@@ -5,7 +5,7 @@ Requires cx_Oracle: http://www.python.net/crew/atuining/cx_Oracle/
 
 import os
 import thread
-from django.db.backends import BaseDatabaseWrapper, BaseDatabaseValidation
+from django.db.backends import BaseDatabaseValidation
 try:
     from django.db.backends.signals import connection_created
 except:
@@ -13,6 +13,7 @@ except:
 # Makes it explicit where the default oracle versions of these components are used
 from django.db.backends.oracle.base import DatabaseFeatures as OracleDatabaseFeatures
 from django.db.backends.oracle.base import DatabaseOperations as OracleDatabaseOperations
+from django.db.backends.oracle.base import DatabaseWrapper as OracleDatabaseWrapper
 from django.db.backends.oracle.client import DatabaseClient as OracleDatabaseClient
 from django.db.backends.oracle.introspection import DatabaseIntrospection as OracleDatabaseIntrospection
 from django.db.backends.oracle.base import FormatStylePlaceholderCursor as OracleFormatStylePlaceholderCursor
@@ -136,7 +137,7 @@ class DatabaseFeatures(OracleDatabaseFeatures):
     time_field_needs_date = True
     date_field_supports_time_value = False
 
-class DatabaseWrapper(BaseDatabaseWrapper):
+class DatabaseWrapper(OracleDatabaseWrapper):
     """ This provides the core connection object wrapper
         for cx_Oracle's pool handling.
         The code is mostly taken from
@@ -172,7 +173,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
     def __init__(self, *args, **kwargs):
         """ Set up the various database components
             Oracle prefixed classes use the standard Oracle
-            version - tested with both 1.0 and 1.2
+            version 
         """
         super(DatabaseWrapper, self).__init__(*args, **kwargs)
         
@@ -207,6 +208,8 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         except:
             # pre django 1.2
             self.validation = BaseDatabaseValidation()            
+        # django 1.6 requires autocommit set on ...    
+        self.autocommit = True
 
     def get_config(self):
         """ Report the oracle connection and pool data see 
@@ -305,6 +308,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         return "%s/%s@%s" % (settings_dict['USER'],
                              settings_dict['PASSWORD'], dsn)
 
+
     def _cursor(self, settings=None):
         """ Get a cursor from the connection pool """
         cursor = None
@@ -373,19 +377,30 @@ class DatabaseWrapper(BaseDatabaseWrapper):
                 self.logger.critical('Pool couldnt be created - please check your Oracle connection or credentials')
             else:
                 raise Exception('Pool couldnt be created - please check your Oracle connection or credentials')
-            
         if not cursor:
             cursor = FormatStylePlaceholderCursor(self.connection, self.logger)
         # Default arraysize of 1 is highly sub-optimal.
         cursor.arraysize = 100
         return cursor
 
+    def get_new_connection(self, conn_params):
+        """ Want a pooled connection """
+        #conn_string = convert_unicode(self._connect_string())
+        #return Database.connect(conn_string, **conn_params)
+        return self._get_alive_connection()
+
+    def create_cursor(self):
+        return self._cursor()
+
     def _get_alive_connection(self):
-        """ Get a connection from the connection pool.  Make sure it's a valid connection (using ping()) before returning it. """        
+        """ Get a connection from the connection pool.  
+            Make sure it's a valid connection (using ping()) before returning it. 
+            Pass on the autocommit -> needs this True for django 1.6 to use atomic transactions
+        """        
         connection_ok = False
         sanity_check = 0
         sanity_threshold = self.extras.get('max',10)
-        
+
         while connection_ok == False:
             new_conn = self.pool.acquire()
             try:
@@ -398,7 +413,9 @@ class DatabaseWrapper(BaseDatabaseWrapper):
                 if self.logger:
                     self.logger.critical('Found a dead connection.  Dropping from pool.')
                 self.pool.drop(new_conn)
-        
+            with self.wrap_database_errors:
+                new_conn.autocommit = self.autocommit
+
         return new_conn
         
     def close(self):
